@@ -3,6 +3,7 @@
 
 #include <QCoreApplication>
 #include <QDebug>
+#include <QTest>
 #include "patternmatcher.h"
 #include "parserengine.h"
 #include "forumparser.h"
@@ -28,6 +29,9 @@ public slots:
 	void loginFinished(bool success, QString motd);
 	void listParsersFinished(QList <ForumParser> parsers);
 	void getParserFinished(ForumParser parser);
+	void subscribeGroupsFinished(bool success);
+	void sendThreadDataFinished(bool success);
+
 private:
 	void runParserEngineTests();
 	void runProtocolTests();
